@@ -119,7 +119,7 @@ ACCESS_SLA_TEMPLATE = {
         "name": "escrowPayment",
         "timelock": 0,
         "timeout": 0,
-        "contractName": "EscrowPayment",
+        "contractName": "EscrowPaymentCondition",
         "functionName": "fulfill",
         "parameters": [
           {
@@ -172,4 +172,4 @@ ACCESS_SLA_TEMPLATE = {
       }
     ]
   }
-}
\ No newline at end of file
+}
